@@ -597,11 +597,11 @@ class PathwayEnrichment:
         '''
         background = list(set(background))
         reactome_database = pd.read_csv(os.path.join(dirname,
-                                                     "../data/UniProt2Reactome_PE_All_Levels.txt"), sep='\t', header=None)
-        reactome_database.columns = ['Accession', 'Reactome_Protein_Name',
-                                     'Compartment', 'Reactome_ID', 'URL', 'Description', 'Evidence_Code', 'Species']
+                                                     "../data/UniProt2Reactome.txt"), sep='\t', header=None)
+        reactome_database.columns = ['Accession', 'Reactome_ID',
+                                      'URL', 'Description', 'Evidence_Code', 'Species']
         reactome_database = reactome_database.drop_duplicates(subset=['Accession', 
-                                     'Compartment', 'Reactome_ID', 'URL', 'Description', 'Evidence_Code', 'Species'])
+                                     'Reactome_ID', 'URL', 'Description', 'Evidence_Code', 'Species'])
         reactome_database['Checked'] = reactome_database['Accession'].isin(
             background)
         reactome_database = reactome_database[reactome_database['Checked'] == True]
@@ -616,12 +616,13 @@ class PathwayEnrichment:
         '''
         # Read file
         reactome_database = pd.read_csv(os.path.join(dirname,
-                                                     "../data/UniProt2Reactome_PE_All_Levels.txt"), sep='\t', header=None)
-        reactome_database.columns = ['Accession', 'Reactome_Protein_Name',
-                                     'Compartment', 'Reactome_ID', 'URL', 'Description', 'Evidence_Code', 'Species']
-        # filter by species
+                                                     "../data/UniProt2Reactome.txt"), sep='\t', header=None)
+        reactome_database.columns = ['Accession', 'Reactome_ID',
+                                      'URL', 'Description', 'Evidence_Code', 'Species']
         reactome_database = reactome_database.drop_duplicates(subset=['Accession', 
                                      'Reactome_ID', 'URL', 'Description', 'Evidence_Code', 'Species'])
+        # filter by species
+        
         reactome_filtered = reactome_database[reactome_database['Species'].str.contains(
             species)]
         # Count proteins per pathway
